from django.template import Library
from django.conf import settings
from django.core.urlresolvers import reverse

from emissions.models import Emission, Episode, NewsItem, SoundFile, Focus
from combo.data.models import Page

register = Library()

@register.filter
def online_url(object):
    if isinstance(object, NewsItem):
        return settings.WEBSITE_BASE_URL + 'actus/' + object.slug
    if isinstance(object, Emission):
        return settings.WEBSITE_BASE_URL + 'emissions/' + object.slug + '/'
    if isinstance(object, Episode):
        return settings.WEBSITE_BASE_URL + 'emissions/' + object.emission.slug + '/' + object.slug + '/'
    if isinstance(object, SoundFile):
        return settings.WEBSITE_BASE_URL + 'emissions/' + object.episode.emission.slug + '/' + object.episode.slug
    if isinstance(object, Page):
        return settings.WEBSITE_BASE_URL + object.get_online_url().strip('/')
    return ''


@register.filter
def context_url(object):
    if isinstance(object, NewsItem) and object.emission:
        return reverse('emission-view', kwargs={'slug': object.emission.slug})
    if isinstance(object, Episode):
        return reverse('emission-view', kwargs={'slug': object.emission.slug})
    if isinstance(object, SoundFile):
        return reverse('emission-view', kwargs={'slug': object.episode.emission.slug})
    return None


@register.filter
def context_title(object):
    if isinstance(object, NewsItem) and object.emission:
        return object.emission.title
    if isinstance(object, Episode):
        return object.emission.title
    if isinstance(object, SoundFile):
        return object.episode.emission.title
    return None


@register.filter
def has_focus(object):
    if isinstance(object, NewsItem):
        object_type = 'newsitem'
    elif isinstance(object, Emission):
        object_type = 'emission'
    elif isinstance(object, Episode):
        object_type = 'episode'
    elif isinstance(object, SoundFile):
        object_type = 'soundfile'
    else:
        return False
    try:
        focus = Focus.objects.get(**{object_type: object})
    except Focus.DoesNotExist:
        return False
    return (focus.current == True)


@register.filter
def unset_focus_url(object):
    if isinstance(object, NewsItem):
        object_type = 'newsitem'
    elif isinstance(object, Emission):
        object_type = 'emission'
    elif isinstance(object, Episode):
        object_type = 'episode'
    elif isinstance(object, SoundFile):
        object_type = 'soundfile'
    return reverse('focus-unset', kwargs={
        'object_type': object_type,
        'object_id': object.id})


@register.filter
def set_focus_url(object):
    if isinstance(object, NewsItem):
        object_type = 'newsitem'
    elif isinstance(object, Emission):
        object_type = 'emission'
    elif isinstance(object, Episode):
        object_type = 'episode'
    elif isinstance(object, SoundFile):
        object_type = 'soundfile'
    return reverse('focus-set', kwargs={
        'object_type': object_type,
        'object_id': object.id})

@register.filter
def can_focus(object):
    if isinstance(object, NewsItem):
        return True
    elif isinstance(object, Emission):
        return True
    elif isinstance(object, Episode):
        return True
    elif isinstance(object, SoundFile):
        return True
    return False


@register.filter
def as_duration(value):
    if not value:
        return '-'
    return '%s:%02d' % (value/60, value%60)
